@@ -1,8 +1,8 @@
 # Paranoid::Network::IPv6 -- IPv6-specific network functions
 #
-# (c) 2012, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: IPv6.pm,v 0.3 2012/09/24 23:20:22 acorliss Exp $
+# $Id: lib/Paranoid/Network/IPv6.pm, 2.01 2016/06/23 00:34:50 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -17,22 +17,22 @@
 
 package Paranoid::Network::IPv6;
 
-use 5.006;
+use 5.008;
 
 use strict;
 use warnings;
 use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use base qw(Exporter);
+use Paranoid;
 use Paranoid::Debug qw(:all);
 use Paranoid::Network::Socket;
-use Carp;
 
 my @base      = qw(ipv6NetConvert ipv6NetPacked ipv6NetIntersect);
 my @constants = qw(MAXIPV6CIDR IPV6REGEX IPV6CIDRRGX IPV6BASE IPV6BRDCST
     IPV6MASK);
 my @ipv6sort = qw(ipv6StrSort ipv6PackedSort ipv6NumSort);
 
-($VERSION) = ( q$Revision: 0.3 $ =~ /(\d+(?:\.(\d+))+)/sm );
+($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
 @EXPORT      = @base;
 @EXPORT_OK   = ( @base, @constants, @ipv6sort );
 %EXPORT_TAGS = (
@@ -47,15 +47,16 @@ use constant IPV6REGEX   => qr/
                             :(?::[abcdef\d]{1,4}){1,7}                 | 
                             [abcdef\d]{1,4}(?:::?[abcdef\d]{1,4}){1,7} | 
                             (?:[abcdef\d]{1,4}:){1,7}: 
-                            /smix;
-use constant IPV6CIDRRGX => qr#(@{[ IPV6REGEX ]})(?:/(\d+))?#sm;
-use constant IPV6BASE    => 0;
-use constant IPV6BRDCST  => 1;
-use constant IPV6MASK    => 2;
-use constant CHUNKMASK   => 0xffffffff;
-use constant CHUNK       => 32;
-use constant IPV6CHUNKS  => 4;
-use constant IPV6LENGTH  => 16;
+                            /six;
+use constant IPV6CIDRRGX =>
+    qr#@{[ IPV6REGEX ]}/(?:1(?:[01]\d|2[0-8])|\d\d?)#s;
+use constant IPV6BASE   => 0;
+use constant IPV6BRDCST => 1;
+use constant IPV6MASK   => 2;
+use constant CHUNKMASK  => 0xffffffff;
+use constant CHUNK      => 32;
+use constant IPV6CHUNKS => 4;
+use constant IPV6LENGTH => 16;
 
 #####################################################################
 #
@@ -63,7 +64,7 @@ use constant IPV6LENGTH  => 16;
 #
 #####################################################################
 
-sub ipv6NetConvert ($) {
+sub ipv6NetConvert {
 
     # Purpose:  Takes a string representation of an IPv6 network
     #           address and returns a list of lists containing
@@ -75,17 +76,19 @@ sub ipv6NetConvert ($) {
     # Usage:    @network = ipv6NetConvert($netAddr);
 
     my $netAddr = shift;
-    my $n = defined $netAddr ? $netAddr : 'undef';
-    my ( $bnet, $bmask, @tmp, @rv );
+    my ( $bnet, $bmask, $t, @tmp, @rv );
 
-    pdebug( "entering w/$n", PDLEVEL1 );
+    pdebug( 'entering w/%s', PDLEVEL1, $netAddr );
     pIn();
 
     if ( has_ipv6() or $] >= 5.012 ) {
 
         # Extract net address, mask
         if ( defined $netAddr ) {
-            ( $bnet, $bmask ) = ( $netAddr =~ m#^@{[ IPV6CIDRRGX ]}$#sm );
+            ($t) =
+                ( $netAddr =~ m#^(@{[ IPV6CIDRRGX ]}|@{[ IPV6REGEX ]})$#s )
+                [0];
+            ( $bnet, $bmask ) = split m#/#s, $t if defined $t;
         }
 
         if ( defined $bnet and length $bnet ) {
@@ -163,12 +166,12 @@ sub ipv6NetConvert ($) {
     }
 
     pOut();
-    pdebug( "leaving w/rv: @rv", PDLEVEL1 );
+    pdebug( 'leaving w/rv: %s', PDLEVEL1, @rv );
 
     return @rv;
 }
 
-sub ipv6NetPacked ($) {
+sub ipv6NetPacked {
 
     # Purpose:  Wrapper script for ipv6NetConvert that repacks all of its
     #           32bit chunks into opaque strings in network-byte order.
@@ -176,10 +179,9 @@ sub ipv6NetPacked ($) {
     # Usage:    @network = ipv6NetPacked($netAddr);
 
     my $netAddr = shift;
-    my $n = defined $netAddr ? $netAddr : 'undef';
     my @rv;
 
-    pdebug( "entering w/$n", PDLEVEL1 );
+    pdebug( 'entering w/%s', PDLEVEL1, $netAddr );
     pIn();
 
     @rv = ipv6NetConvert($netAddr);
@@ -188,12 +190,12 @@ sub ipv6NetPacked ($) {
     }
 
     pOut();
-    pdebug( "leaving w/@rv", PDLEVEL1 );
+    pdebug( 'leaving w/%s', PDLEVEL1, @rv );
 
     return @rv;
 }
 
-sub _cmpArrays ($$) {
+sub _cmpArrays {
 
     # Purpose:  Compares IPv6 chunked address arrays
     # Returns:  -1:  net1 < net 2
@@ -205,7 +207,7 @@ sub _cmpArrays ($$) {
     my $aref2 = shift;
     my $rv    = 0;
 
-    pdebug( "entering w/$aref1, $aref2", PDLEVEL2 );
+    pdebug( 'entering w/%s, %s', PDLEVEL2, $aref1, $aref2 );
     pIn();
 
     while ( scalar @$aref1 ) {
@@ -218,12 +220,12 @@ sub _cmpArrays ($$) {
     }
 
     pOut();
-    pdebug( "leaving w/rv: $rv", PDLEVEL2 );
+    pdebug( 'leaving w/rv: %s', PDLEVEL2, $rv );
 
     return $rv;
 }
 
-sub ipv6NetIntersect (@) {
+sub ipv6NetIntersect {
 
     # Purpose:  Tests whether network address ranges intersect
     # Returns:  Integer, denoting whether an intersection exists, and what
@@ -237,12 +239,10 @@ sub ipv6NetIntersect (@) {
 
     my $tgt  = shift;
     my $dest = shift;
-    my $t    = defined $tgt ? $tgt : 'undef';
-    my $d    = defined $dest ? $dest : 'undef';
     my $rv   = 0;
     my ( @tnet, @dnet );
 
-    pdebug( "entering w/$t, $d", PDLEVEL1 );
+    pdebug( 'entering w/%s, %s', PDLEVEL1, $tgt, $dest );
     pIn();
 
     # Bypas if one or both isn't defined -- obviously no intersection
@@ -284,7 +284,7 @@ sub ipv6NetIntersect (@) {
     }
 
     pOut();
-    pdebug( "leaving w/rv: $rv", PDLEVEL1 );
+    pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
 
     return $rv;
 }
@@ -336,9 +336,9 @@ sub ipv6NetIntersect (@) {
         my $b1    = ${"${pkg}::b"};
         my ( $i, $rv );
 
-        $a1 =~ s#/.+##sm;
+        $a1 =~ s#/.+##s;
         $a1 = [ unpack 'NNNN', inet_pton( AF_INET6(), $a1 ) ];
-        $b1 =~ s#/.+##sm;
+        $b1 =~ s#/.+##s;
         $b1 = [ unpack 'NNNN', inet_pton( AF_INET6(), $b1 ) ];
 
         foreach $i ( 0 .. 3 ) {
@@ -360,7 +360,7 @@ Paranoid::Network::IPv6 - IPv6-related functions
 
 =head1 VERSION
 
-$Id: IPv6.pm,v 0.3 2012/09/24 23:20:22 acorliss Exp $
+$Id: lib/Paranoid/Network/IPv6.pm, 2.01 2016/06/23 00:34:50 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -480,13 +480,7 @@ Simply put: 128.  This is the largest CIDR notation supported in IPv6.
 
 =head2 IPV6REGEX
 
-Regular expression: 
-
-                            qr/
-                            :(?::[abcdef\d]{1,4}){1,7}                 | 
-                            [abcdef\d]{1,4}(?:::?[abcdef\d]{1,4}){1,7} | 
-                            (?:[abcdef\d]{1,4}:){1,7}: 
-                            /smix;
+Regular expression.
 
 You can use this for validating IP addresses as such:
 
@@ -494,19 +488,15 @@ You can use this for validating IP addresses as such:
 
 or to extract potential IPs from  extraneous text:
 
-    (@ips) = ( $string =~ m#(@{[ IPV6REGEX ]})#g);
+    @ips = ( $string =~ m#(@{[ IPV6REGEX ]})#g);
 
 =head2 IPV6CIDRRGX
 
-Regular expression: 
+Regular expression.
 
-    qr#(@{[ IPV6REGEX ]})(?:/(\d+))?#sm
+By default this will extract CIDR notation network addresses:
 
-By default this will extract an IP or CIDR notation network address:
-
-    ($net, $mask) = ( $ip =~ m#^@{[ IPV6CIDRRGX ]}$# );
-
-In the case of a simple IP address B<$mask> will be undefined.
+    @networks = ( $string =~ m#(@{[ IPV6CIDRRGX ]})#si );
 
 =head2 IPV6BASE
 
@@ -533,6 +523,10 @@ L<Paranoid>
 
 =item o
 
+L<Paranoid::Debug>
+
+=item o
+
 L<Paranoid::Network::Socket>
 
 =back
@@ -548,5 +542,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2012, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
 
